@@ -2,16 +2,16 @@ Run.StatCharrms <-
 function(){
 #' @export
 #Main function call for StatCharrms and brings up into screen 
-IntroWindow<-gwindow(horizontal = FALSE,"StatCharrms ", visible=FALSE)
+IntroWindow<-gwindow("StatCharrms ", visible=FALSE)
 size(IntroWindow)<-c(800,600)
-IntroTextframe<-gframe(horizontal = FALSE, container=IntroWindow,where="center")
-IntroTextMessage1<-glabel('Welcome to StatCharrms',container=IntroTextframe,where="center") #Title1
+IntroTextframe<-gframe(horizontal = FALSE, container=IntroWindow)
+IntroTextMessage1<-glabel('Welcome to StatCharrms',container=IntroTextframe) #Title1
 font(IntroTextMessage1)<-list(size=34)
-IntroTextMessage2<-glabel('v0.90.92 February 11, 2019',container=IntroTextframe,where="center") #Title2  #Update This
+IntroTextMessage2<-glabel('v0.90.95 April 30, 2020',container=IntroTextframe) #Title2  #Update This
 font(IntroTextMessage2)<-list(size=16)
-IntroTextMessage3<-glabel('Beta -Developmental-',container=IntroTextframe,where="center") #Title2
+IntroTextMessage3<-glabel('Beta -Developmental-',container=IntroTextframe) #Title2
 font(IntroTextMessage3)<-list(size=16)
-BlankSpace<-gframe(container=IntroTextframe,where="center") #Blank space for formats
+BlankSpace<-gframe(container=IntroTextframe) #Blank space for formats
 size(BlankSpace)<-c(1,80)
 
 ButtonBox1<-ggroup(container=IntroTextframe,horizontal = FALSE) #Read me file  
@@ -22,7 +22,7 @@ font(ReadMeButton)<-list(size=16)
 ExampleButton<-gbutton("Examples ",container=ButtonBox1,where='center',   
 handler= function(h,...){generateExamples()})
 font(ExampleButton)<-list(size=16)
-ButtonBox2<-gframe(horizontal = FALSE,container=ButtonBox1,where="center")
+ButtonBox2<-gframe(horizontal = FALSE,container=ButtonBox1)
 HistoButton<-gbutton("Histology Analysis",container=ButtonBox2,where='center',   #
 handler= function(h,...){Histopath()})
 font(HistoButton)<-list(size=16)
@@ -64,3 +64,17 @@ https://support.rstudio.com/hc/en-us/articles/219949047-Installing-older-version
 message(Message)
 }
 }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
